==> intel-compute-runtime-24.35.30872.32.tar.gz: compute-runtime-24.35.30872.32/shared/test/common/helpers/dispatch_flags_helper.h <==
/*
 * Copyright (C) 2019-2024 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once
#include "shared/source/command_stream/csr_definitions.h"
#include "shared/source/command_stream/csr_properties_flags.h"

using namespace NEO;

struct DispatchFlagsHelper {
    static DispatchFlags createDefaultDispatchFlags() {
        return DispatchFlags(
            nullptr,                                 // barrierTimestampPacketNodes
            {},                                      // pipelineSelectArgs
            nullptr,                                 // flushStampReference
            QueueThrottle::MEDIUM,                   // throttle
            PreemptionMode::Disabled,                // preemptionMode
            GrfConfig::defaultGrfNumber,             // numGrfRequired
            L3CachingSettings::l3CacheOn,            // l3CacheSettings
            ThreadArbitrationPolicy::NotPresent,     // threadArbitrationPolicy
            AdditionalKernelExecInfo::notApplicable, // additionalKernelExecInfo
            KernelExecutionType::notApplicable,      // kernelExecutionType
            MemoryCompressionState::notApplicable,   // memoryCompressionState
            QueueSliceCount::defaultSliceCount,      // sliceCount
            false,                                   // blocking
            false,                                   // dcFlush
            false,                                   // useSLM
            false,                                   // guardCommandBufferWithPipeControl
            false,                                   // gsba32BitRequired
            false,                                   // lowPriority
            false,                                   // implicitFlush
            false,                                   // outOfOrderExecutionAllowed
            false,                                   // epilogueRequired
            false,                                   // usePerDssBackedBuffer
            false,                                   // areMultipleSubDevicesInContext
            false,                                   // memoryMigrationRequired
            false,                                   // textureCacheFlush
            false,                                   // hasStallingCmds
            false,                                   // hasRelaxedOrderingDependencies
            false,                                   // stateCacheInvalidation
            false,                                   // isStallingCommandsOnNextFlushRequired
            false,                                   // isDcFlushRequiredOnStallingCommandsOnNextFlush
            true                                     // disableGlobalSSH
        );
    }
};

==> intel-compute-runtime_24.52.32224.13.orig.tar.gz: compute-runtime-24.52.32224.13/shared/test/common/helpers/dispatch_flags_helper.h <==
/*
 * Copyright (C) 2019-2024 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once
#include "shared/source/command_stream/csr_definitions.h"
#include "shared/source/command_stream/csr_properties_flags.h"

using namespace NEO;

struct DispatchFlagsHelper {
    static DispatchFlags createDefaultDispatchFlags() {
        return DispatchFlags(
            nullptr,                                 // barrierTimestampPacketNodes
            {},                                      // pipelineSelectArgs
            nullptr,                                 // flushStampReference
            QueueThrottle::MEDIUM,                   // throttle
            PreemptionMode::Disabled,                // preemptionMode
            GrfConfig::defaultGrfNumber,             // numGrfRequired
            L3CachingSettings::l3CacheOn,            // l3CacheSettings
            ThreadArbitrationPolicy::NotPresent,     // threadArbitrationPolicy
            AdditionalKernelExecInfo::notApplicable, // additionalKernelExecInfo
            KernelExecutionType::notApplicable,      // kernelExecutionType
            MemoryCompressionState::notApplicable,   // memoryCompressionState
            QueueSliceCount::defaultSliceCount,      // sliceCount
            false,                                   // blocking
            false,                                   // dcFlush
            false,                                   // useSLM
            false,                                   // guardCommandBufferWithPipeControl
            false,                                   // gsba32BitRequired
            false,                                   // lowPriority
            false,                                   // implicitFlush
            false,                                   // outOfOrderExecutionAllowed
            false,                                   // epilogueRequired
            false,                                   // usePerDssBackedBuffer
            false,                                   // areMultipleSubDevicesInContext
            false,                                   // memoryMigrationRequired
            false,                                   // textureCacheFlush
            false,                                   // hasStallingCmds
            false,                                   // hasRelaxedOrderingDependencies
            false,                                   // stateCacheInvalidation
            false,                                   // isStallingCommandsOnNextFlushRequired
            false                                    // isDcFlushRequiredOnStallingCommandsOnNextFlush
        );
    }
};
